==> lucide_py-0.1.0-py3-none-any.whl: lucide/icons/locate_off.py <==
from .. import IconBase


class IconLocateOff(IconBase):
    class_name = "lucide lucide-locate-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "line": {
                "x1": "2",
                "x2": "5",
                "y1": "12",
                "y2": "12"
            }
        },
        {
            "line": {
                "x1": "19",
                "x2": "22",
                "y1": "12",
                "y2": "12"
            }
        },
        {
            "line": {
                "x1": "12",
                "x2": "12",
                "y1": "2",
                "y2": "5"
            }
        },
        {
            "line": {
                "x1": "12",
                "x2": "12",
                "y1": "19",
                "y2": "22"
            }
        },
        {
            "path": {
                "d": "M7.11 7.11C5.83 8.39 5 10.1 5 12c0 3.87 3.13 7 7 7 1.9 0 3.61-.83 4.89-2.11"
            }
        },
        {
            "path": {
                "d": "M18.71 13.96c.19-.63.29-1.29.29-1.96 0-3.87-3.13-7-7-7-.67 0-1.33.1-1.96.29"
            }
        },
        {
            "line": {
                "x1": "2",
                "x2": "22",
                "y1": "2",
                "y2": "22"
            }
        }
    ]
}

==> lucide_py-0.1.1-py3-none-any.whl: lucide/icons/locate_off.py <==
from .. import IconBase


class IconLocateOff(IconBase):
    class_name = "lucide lucide-locate-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "view_box": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "line": {
                "x1": "2",
                "x2": "5",
                "y1": "12",
                "y2": "12"
            }
        },
        {
            "line": {
                "x1": "19",
                "x2": "22",
                "y1": "12",
                "y2": "12"
            }
        },
        {
            "line": {
                "x1": "12",
                "x2": "12",
                "y1": "2",
                "y2": "5"
            }
        },
        {
            "line": {
                "x1": "12",
                "x2": "12",
                "y1": "19",
                "y2": "22"
            }
        },
        {
            "path": {
                "d": "M7.11 7.11C5.83 8.39 5 10.1 5 12c0 3.87 3.13 7 7 7 1.9 0 3.61-.83 4.89-2.11"
            }
        },
        {
            "path": {
                "d": "M18.71 13.96c.19-.63.29-1.29.29-1.96 0-3.87-3.13-7-7-7-.67 0-1.33.1-1.96.29"
            }
        },
        {
            "line": {
                "x1": "2",
                "x2": "22",
                "y1": "2",
                "y2": "22"
            }
        }
    ]
}
